@@ -63,7 +63,7 @@ Because perl5i I<plans> to be incompatible in the future, you do not
 simply C<use perl5i>.  You must declare which major version of perl5i
 you are using.  You do this like so:
 
-    # Use perl5i major version 1
+    # Use perl5i major version 2
     use perl5i::2;
 
 Thus the code you write with, for example, C<perl5i::2> will always
@@ -111,6 +111,124 @@ C<mo> was chosen to avoid clashing with Moose's meta object.
 See L<perl5i::Meta> for complete details.
 
 
+=head2 Subroutine and Method Signatures
+
+perl5i makes it easier to declare what parameters a subroutine takes.
+
+    func hello($place) {
+        say "Hello, $place!\n";
+    }
+
+    method get($key) {
+        return $self->{$key};
+    }
+
+    method new($class: %args) {
+        return bless \%args, $class;
+    }
+
+C<func> and C<method> define subroutines as C<sub> does, with some
+extra conveniences.
+
+The signature syntax is currently very simple.  The content will be
+assigned from @_.  This:
+
+    func add($this, $that) {
+        return $this + $that;
+    }
+
+is equivalent to:
+
+    sub add {
+        my($this, $that) = @_;
+        return $this + $that;
+    }
+
+C<method> defines a method.  This is the same as a subroutine, but the
+first argument, the I<invocant>, will be removed and made into
+C<$self>.
+
+    method get($key) {
+        return $self->{$key};
+    }
+
+    sub get {
+        my $self = shift;
+        my($key) = @_;
+        return $self->{$key};
+    }
+
+Methods have a special bit of syntax.  If the first item in the
+siganture is C<$var:> it will change the variable used to store the
+invocant.
+
+    method new($class: %args) {
+        return bless $class, \%args;
+    }
+
+is equivalent to:
+
+    sub new {
+        my $class = shift;
+        my %args = @_;
+        return bless $class, \%args;
+    }
+
+Anonymous functions and methods work, too.
+
+    my $code = func($message) { say $message };
+
+Guarantees include:
+
+  @_ will not be modified except by removing the invocant
+
+Future versions of perl5i will add to the signature syntax and
+capabilities.  Planned expansions include:
+
+  Signature validation
+  Signature documentation
+  Named parameters
+  Required parameters
+  Read only parameters
+  Aliased parameters
+  Anonymous method and function declaration
+  Variable method and function names
+  Parameter traits
+  Traditional prototypes
+
+See L<http://github.com/schwern/perl5i/issues/labels/syntax#issue/19> for
+more details about future expansions.
+
+The equivalencies above should only be taken for illustrative
+purposes, they are not guaranteed to be literally equivalent.
+
+Note that while all parameters are optional by default, the number of
+parameters will eventually be enforced.  For example, right now this
+will work:
+
+    func add($this, $that) { return $this + $that }
+
+    say add(1,2,3);  # says 3
+
+The extra argument is ignored.  In future versions of perl5i this will
+be a runtime error.
+
+
+=head3 Signature Introspection
+
+The signature of a subroutine defined with C<func> or C<method> can be
+queried by calling the C<signature> method on the code reference.
+
+    func hello($greeting, $place) { say "$greeting, $place" }
+
+    my $code = \&hello;
+    say $code->signature->num_positional_params;  # prints 2
+
+Functions defined with C<sub> will not have a signature.
+
+See L<perl5i::Signature> for more details.
+
+
 =head2 Autoboxing
 
 L<autobox> allows methods to be defined for and called on most
@@ -121,7 +239,7 @@ functionality without polluting the global namespace.
 L<autobox::Core> wraps a lot of Perl's built in functions so they can
 be called as methods on unblessed variables.  C<< @a->pop >> for example.
 
-=head2 alias()
+=head3 alias()
 
     $scalar_reference->alias( @identifiers );
     @alias->alias( @identifiers );
@@ -132,7 +250,7 @@ Aliases a variable to a new global name.
 
     my $code = sub { 42 };
     $code->alias( "foo" );
-    print foo();        # prints 42
+    say foo();        # prints 42
 
 It will work on everything except scalar references.
 
@@ -153,7 +271,7 @@ qualified name for the alias.
     my $class = "Some::Class";
     my $name  = "foo";
     sub { 99 }->alias( $class, $name );
-    print Some::Class->foo;  # prints 99
+    say Some::Class->foo;  # prints 99
 
 If there is just one @identifier and it has no "::" in it, the current
 caller will be prepended.  C<< $thing->alias("name") >> is shorthand for
@@ -196,15 +314,15 @@ than C<< $string->length >> it will just return C<$string>.
 
     say "Hello"->center(4);        # "Hello";
 
-=head2 round
+=head3 round
 
     my $rounded_number = $number->round;
 
 Round to the nearest integer.
 
-=head2 round_up
+=head3 round_up
 
-=head2 ceil
+=head3 ceil
 
     my $new_number = $number->round_up;
 
@@ -216,9 +334,9 @@ Rounds the $number towards infinity.
 ceil() is a synonym for round_up().
 
 
-=head2 round_down
+=head3 round_down
 
-=head2 floor
+=head3 floor
 
     my $new_number = $number->round_down;
 
@@ -230,7 +348,7 @@ Rounds the $number towards negative infinity.
 floor() is a synonyn for round_down().
 
 
-=head2 is_number
+=head3 is_number
 
     $is_a_number = $thing->is_number;
 
@@ -240,7 +358,7 @@ Returns true if $thing is a number understood by Perl.
     "12.34"->is_number;         # also true
     "eleven"->is_number;        # false
 
-=head2 is_positive
+=head3 is_positive
 
     $is_positive = $thing->is_positive;
 
@@ -248,7 +366,7 @@ Returns true if $thing is a positive number.
 
 0 is not positive.
 
-=head2 is_negative
+=head3 is_negative
 
     $is_negative = $thing->is_negative;
 
@@ -256,7 +374,19 @@ Returns true if $thing is a negative number.
 
 0 is not negative.
 
-=head2 is_integer
+=head3 is_even
+
+    $is_even = $thing->is_even;
+
+Returns true if $thing is an even integer.
+
+=head3 is_odd
+
+    $is_odd = $thing->is_odd;
+
+Returns true if $thing is an odd integer.
+
+=head3 is_integer
 
     $is_an_integer = $thing->is_integer;
 
@@ -266,11 +396,11 @@ Returns true if $thing is an integer.
     12.34->is_integer;          # false
     "eleven"->is_integer;       # false
 
-=head2 is_int
+=head3 is_int
 
 A synonym for is_integer
 
-=head2 is_decimal
+=head3 is_decimal
 
     $is_a_decimal_number = $thing->is_decimal;
 
@@ -281,7 +411,7 @@ Returns true if $thing is a decimal number.
     ".34"->is_decimal;          # true
     "point five"->is_decimal;   # false
 
-=head2 require
+=head3 require
 
     my $module = $module->require;
 
@@ -353,7 +483,7 @@ For example,
 It will throw an exception if given something which could not be a
 path to a Perl module.
 
-=head2 module2path()
+=head3 module2path()
 
     my $path = $module->module2path;
 
@@ -436,6 +566,30 @@ order to allow chaining.
 
     @array->grep(sub{ $_->is_number })->sum->say;
 
+=head3 foreach()
+
+    @array->foreach( func($item) { ... } );
+
+Works like the built in C<foreach>, calls the code block for each
+element of @array passing it into the block.
+
+    @array->foreach( func($item) { say $item } );  # print each item
+
+It will pass in as many elements as the code block accepts.  This
+allows you to iterate through an array 2 at a time, or 3 or 4 or
+whatever.
+
+    my @names = ("Joe", "Smith", "Jim", "Dandy", "Jane", "Lane");
+    @names->foreach( func($fname, $lname) {
+        say "Person: $fname $lname";
+    });
+
+A normal subroutine with no signature will get one at a time.
+
+If @array is not a multiple of the iteration (for example, @array has
+5 elements and you ask 2 at a time) the behavior is currently undefined.
+
+
 =head3 diff()
 
 Calculate the difference between two (or more) arrays:
@@ -572,6 +726,20 @@ C<< @array->diff >>.
 Returns the key/value pairs that are present simultaneously in all the
 hash arguments.  Otherwise works as C<< @array->intersect >>.
 
+=head2 Code autoboxing
+
+=head3 signature
+
+    my $sig = $code->signature;
+
+You can query the signature of any code reference defined with C<func>
+or C<method>.  See L<Signature Introspection> for details.
+
+If C<$code> has a signature, returns an object representing C<$code>'s
+signature.  See L<perl5i::Signature> for details.  Otherwise it
+returns nothing.
+
+
 =head2 caller()
 
 L<Perl6::Caller> causes C<caller> to return an object in scalar
@@ -601,10 +769,109 @@ STDOUT, STDIN, STDERR and all newly opened filehandles will have UTF8
 encoding turned on.  Consequently, if you want to output raw bytes to
 a file, such as outputting an image, you must set C<< binmode $fh >>.
 
+=head2 capture()
+
+    my($stdout, $stderr) = capture { ... } %options;
+    my $stdout = capture { ... } %options;
+
+C<capture()> lets you capture all output to C<STDOUT> and C<STDERR> in
+any block of code.
+
+    # $out = "Hello"
+    # $err = "Bye"
+    my($out, $err) = capture {
+        print "Hello";
+        print STDERR "Bye";
+    };
+
+If called in scalar context, it will only return C<STDOUT> and silence C<STDERR>.
+
+    # $out = "Hello"
+    my $out = capture {
+        print "Hello";
+        warn "oh god";
+    };
+
+C<capture> takes some options.
+
+=over 4
+
+=item B<tee>
+
+tee will cause output to be captured yet still printed.
+
+    my $out = capture { print "Hi" } tee => 1;
+
+=item B<merge>
+
+merge will merge C<STDOUT> and C<STDERR> into one variable.
+
+    # $out = "HiBye"
+    my $out = capture {
+        print "Hi";
+        print STDERR "Bye";
+    } merge => 1;
+
+=back
+
 =head2 Carp
 
 C<croak> and C<carp> from L<Carp> are always available.
 
+=head2 Child
+
+L<Child> provides the C<child> function which is a better way to do forking.
+
+C<child> creates and starts a child process, and returns an
+L<Child::Link::Proc> object which is a better interface for managing the child
+process. The only required argument is a codeblock, which is called in the new
+process. exit() is automatically called for you after the codeblock returns.
+
+    my $proc = child {
+        my $parent = shift;
+        ...
+    };
+
+You can also request a pipe for IPC:
+
+    my $proc = child {
+        my $parent = shift;
+
+        $parent->say("Message");
+        my $reply = $parent->read();
+
+        ...
+    } pipe => 1;
+
+    my $message = $proc->read();
+    $proc->say("reply");
+
+API Overview: (See L<Child> for more information)
+
+=over 4
+
+=item $proc->is_complete()
+
+=item $proc->wait()
+
+=item $proc->kill($SIG)
+
+=item $proc->pid()
+
+=item $proc->exit_status()
+
+=item $parent->pid()
+
+=item $parent->detach()
+
+=item $proc_or_parent->read()
+
+=item $proc_or_parent->write( @MESSAGES )
+
+=item $proc_or_parent->say( @MESSAGES )
+
+=back
+
 =head2 English
 
 L<English> gives English names to the punctuation variables; for
@@ -725,6 +992,24 @@ of $@ and a nice syntax layer:
 
 See perldoc L<Try::Tiny> for details.
 
+
+=head2 true
+
+You no longer have to put a true value at the end of a module which uses perl5i.
+
+
+=head2 Better load errors
+
+Most of us have learned the meaning of the dreaded "Can't locate Foo.pm in
+@INC". Admittedly though, it's not the most helpful of the error messages. In
+perl5i we provide a much friendlier error message.
+
+Example:
+
+    Can't locate My/Module.pm in your Perl library.  You may need to install it
+    from CPAN or another repository.  Your library paths are:
+        Indented list of paths, 1 per line...
+
 =head1 Command line program
 
 There is a perl5i command line program installed with perl5i (Windows
@@ -794,7 +1079,7 @@ Copyright 2009-2010, Michael G Schwern <schwern@pobox.com>
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See L<http://dev.perl.org/licenses/artistic.html>
 
 
 =head1 SEE ALSO
